==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiWidgets/QGraphicsWidget_shell.h <==
#ifndef QGRAPHICSWIDGET_SHELL_H
#define QGRAPHICSWIDGET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qtransform.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicslayout.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicslayoutitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicssceneevent.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicstransform.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(graphicsview)

class QGraphicsWidget_shell : public QGraphicsWidget, public QtJambiShellInterface
{
public:
    QGraphicsWidget_shell(QGraphicsItem* parent0 = nullptr, Qt::WindowFlags wFlags1 = Qt::WindowFlags());
    ~QGraphicsWidget_shell() override;

    void advance(int phase0) override;
    QRectF boundingRect() const override;
    void changeEvent(QEvent* event0) override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* event0) override;
    bool collidesWithItem(const QGraphicsItem* other0, Qt::ItemSelectionMode mode1) const override;
    bool collidesWithPath(const QPainterPath& path0, Qt::ItemSelectionMode mode1) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragLeaveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragMoveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dropEvent(QGraphicsSceneDragDropEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QVariant extension(const QVariant& variant0) const override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    void getContentsMargins(qreal* left0, qreal* top1, qreal* right2, qreal* bottom3) const override;
    void grabKeyboardEvent(QEvent* event0) override;
    void grabMouseEvent(QEvent* event0) override;
    void hideEvent(QHideEvent* event0) override;
    void hoverEnterEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverMoveEvent(QGraphicsSceneHoverEvent* event0) override;
    void initStyleOption(QStyleOption* option0) const override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isEmpty() const override;
    bool isObscuredBy(const QGraphicsItem* item0) const override;
    QVariant itemChange(QGraphicsItem::GraphicsItemChange change0, const QVariant& value1) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event0) override;
    void mousePressEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event0) override;
    void moveEvent(QGraphicsSceneMoveEvent* event0) override;
    QPainterPath opaqueArea() const override;
    void paint(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    void paintWindowFrame(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    void polishEvent() override;
    QVariant propertyChange(const QString& propertyName0, const QVariant& value1) override;
    void resizeEvent(QGraphicsSceneResizeEvent* event0) override;
    bool sceneEvent(QEvent* event0) override;
    bool sceneEventFilter(QGraphicsItem* watched0, QEvent* event1) override;
    void setExtension(QGraphicsItem::Extension extension0, const QVariant& variant1) override;
    void setGeometry(const QRectF& rect0) override;
    QPainterPath shape() const override;
    void showEvent(QShowEvent* event0) override;
    QSizeF sizeHint(Qt::SizeHint which0, const QSizeF& constraint1) const override;
    bool supportsExtension(QGraphicsItem::Extension extension0) const override;
    void timerEvent(QTimerEvent* event0) override;
    void ungrabKeyboardEvent(QEvent* event0) override;
    void ungrabMouseEvent(QEvent* event0) override;
    void updateGeometry() override;
    void wheelEvent(QGraphicsSceneWheelEvent* event0) override;
    bool windowFrameEvent(QEvent* e0) override;
    Qt::WindowFrameSection windowFrameSectionAt(const QPointF& pos0) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsWidget_access : public QGraphicsWidget
{
    void __qt_setGraphicsItem_QGraphicsItem_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0);
    void __qt_setOwnedByLayout_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean ownedByLayout0);
    jobject __qt_boundingRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_changeEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_closeEvent_QCloseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_focusNextPrevChild_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean next0);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_getContentsMargins_qreal_ptr_qreal_ptr_qreal_ptr_qreal_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdoubleArray left0) const;
    void __qt_grabKeyboardEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_grabMouseEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hideEvent_QHideEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverLeaveEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverMoveEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_initStyleOption_QStyleOption_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0) const;
    jboolean __qt_isEmpty(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_itemChange_QGraphicsItem_GraphicsItemChange_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint change0, jobject value1);
    void __qt_moveEvent_QGraphicsSceneMoveEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_paint_QPainter_ptr_const_QStyleOptionGraphicsItem_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID widget2);
    void __qt_paintWindowFrame_QPainter_ptr_const_QStyleOptionGraphicsItem_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID widget2);
    void __qt_polishEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_propertyChange_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring propertyName0, jobject value1);
    void __qt_resizeEvent_QGraphicsSceneResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_sceneEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_setGeometry_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0);
    jobject __qt_shape(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_showEvent_QShowEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_sizeHint_Qt_SizeHint_cref_QSizeF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint which0, QtJambiNativeID constraint1) const;
    void __qt_ungrabKeyboardEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_ungrabMouseEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_updateGeometry(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_windowFrameEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jint __qt_windowFrameSectionAt_cref_QPointF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pos0) const;
};

#endif // QT_CONFIG(graphicsview)
#endif // QGRAPHICSWIDGET_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiWidgets/QGraphicsWidget_shell.h <==
#ifndef QGRAPHICSWIDGET_SHELL_H
#define QGRAPHICSWIDGET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qtransform.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicslayout.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicslayoutitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicssceneevent.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicstransform.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(graphicsview)

class QGraphicsWidget_shell : public QGraphicsWidget, public QtJambiShellInterface
{
public:
    QGraphicsWidget_shell(QGraphicsItem* parent0 = nullptr, Qt::WindowFlags wFlags1 = Qt::WindowFlags());
    ~QGraphicsWidget_shell() override;

    void advance(int phase0) override;
    QRectF boundingRect() const override;
    void changeEvent(QEvent* event0) override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* event0) override;
    bool collidesWithItem(const QGraphicsItem* other0, Qt::ItemSelectionMode mode1) const override;
    bool collidesWithPath(const QPainterPath& path0, Qt::ItemSelectionMode mode1) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragLeaveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragMoveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dropEvent(QGraphicsSceneDragDropEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QVariant extension(const QVariant& variant0) const override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    void getContentsMargins(qreal* left0, qreal* top1, qreal* right2, qreal* bottom3) const override;
    void grabKeyboardEvent(QEvent* event0) override;
    void grabMouseEvent(QEvent* event0) override;
    void hideEvent(QHideEvent* event0) override;
    void hoverEnterEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverMoveEvent(QGraphicsSceneHoverEvent* event0) override;
    void initStyleOption(QStyleOption* option0) const override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isEmpty() const override;
    bool isObscuredBy(const QGraphicsItem* item0) const override;
    QVariant itemChange(QGraphicsItem::GraphicsItemChange change0, const QVariant& value1) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event0) override;
    void mousePressEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event0) override;
    void moveEvent(QGraphicsSceneMoveEvent* event0) override;
    QPainterPath opaqueArea() const override;
    void paint(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    void paintWindowFrame(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    void polishEvent() override;
    QVariant propertyChange(const QString& propertyName0, const QVariant& value1) override;
    void resizeEvent(QGraphicsSceneResizeEvent* event0) override;
    bool sceneEvent(QEvent* event0) override;
    bool sceneEventFilter(QGraphicsItem* watched0, QEvent* event1) override;
    void setExtension(QGraphicsItem::Extension extension0, const QVariant& variant1) override;
    void setGeometry(const QRectF& rect0) override;
    QPainterPath shape() const override;
    void showEvent(QShowEvent* event0) override;
    QSizeF sizeHint(Qt::SizeHint which0, const QSizeF& constraint1) const override;
    bool supportsExtension(QGraphicsItem::Extension extension0) const override;
    void timerEvent(QTimerEvent* event0) override;
    void ungrabKeyboardEvent(QEvent* event0) override;
    void ungrabMouseEvent(QEvent* event0) override;
    void updateGeometry() override;
    void wheelEvent(QGraphicsSceneWheelEvent* event0) override;
    bool windowFrameEvent(QEvent* e0) override;
    Qt::WindowFrameSection windowFrameSectionAt(const QPointF& pos0) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsWidget_access : public QGraphicsWidget
{
    void __qt_setGraphicsItem_QGraphicsItem_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0);
    void __qt_setOwnedByLayout_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean ownedByLayout0);
    jobject __qt_boundingRect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_changeEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_closeEvent_QCloseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_focusNextPrevChild_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean next0);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_getContentsMargins_qreal_ptr_qreal_ptr_qreal_ptr_qreal_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdoubleArray left0) const;
    void __qt_grabKeyboardEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_grabMouseEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hideEvent_QHideEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverLeaveEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverMoveEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_initStyleOption_QStyleOption_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0) const;
    jboolean __qt_isEmpty_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_itemChange_QGraphicsItem_GraphicsItemChange_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint change0, jobject value1);
    void __qt_moveEvent_QGraphicsSceneMoveEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_paint_QPainter_ptr_const_QStyleOptionGraphicsItem_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID widget2);
    void __qt_paintWindowFrame_QPainter_ptr_const_QStyleOptionGraphicsItem_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID widget2);
    void __qt_polishEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_propertyChange_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring propertyName0, jobject value1);
    void __qt_resizeEvent_QGraphicsSceneResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_sceneEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_setGeometry_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0);
    jobject __qt_shape_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_showEvent_QShowEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_sizeHint_Qt_SizeHint_cref_QSizeF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint which0, QtJambiNativeID constraint1) const;
    void __qt_ungrabKeyboardEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_ungrabMouseEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_updateGeometry(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_windowFrameEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jint __qt_windowFrameSectionAt_cref_QPointF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pos0) const;
};

#endif // QT_CONFIG(graphicsview)
#endif // QGRAPHICSWIDGET_SHELL_H
